/* *********************************************************************** *
 * Copyright (C) 2009 by Ulrich Van Den Hekke                              *
 * ulrich.vdh@shadoware.org                                                *
 *                                                                         *
 * This program is free software: you can redistribute it and/or modify    *
 * it under the terms of the GNU General Public License as published by    *
 * the Free Software Foundation, either version 3 of the License, or       *
 * (at your option) any later version.                                     *
 *                                                                         *
 * This program is distributed in the hope that it will be useful,         *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 * GNU General Public License for more details.                            *
 *                                                                         *
 * You should have received a copy of the GNU General Public License       *
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.   *
 * *********************************************************************** */

// Xml Parser Benchmark
#include "xmlparserbenchmark.h"

// Parsers
#include "expatparser.h"
#include "libxml2parser.h"
#include "oracleparser.h"
#include "qtparser.h"
#include "scewparser.h"
#include "tinyparser.h"
#include "xercescppparser.h"

// Qt header
#include <QTest>
#include <QDir>
#include <QFileInfo>

/* XmlParserBenchmark */

QStringList XmlParserBenchmark::listOfXml() {
	QStringList datas;
	datas << QDir::current().absoluteFilePath( "file250k.xml" );
	datas << QDir::current().absoluteFilePath( "file9300k.xml" );
	datas << QDir::current().absoluteFilePath( "file11300k.xml" );
	return datas;
}

void XmlParserBenchmark::qtDomParser_data() {
	QStringList filenames = listOfXml();

	QTest::addColumn<QString>( "filename" );
	foreach( QString filename, filenames ) {
		QTest::newRow( qPrintable( QFileInfo( filename ).fileName() ) ) << filename;
	}
}

void XmlParserBenchmark::libxml2DomParser_data() {
	QStringList filenames = listOfXml();

	QTest::addColumn<QString>( "filename" );
	foreach( QString filename, filenames ) {
		QTest::newRow( qPrintable( QFileInfo( filename ).fileName() ) ) << filename;
	}
}

void XmlParserBenchmark::libexpatParser_data() {
	QStringList filenames = listOfXml();

	QTest::addColumn<QString>( "filename" );
	foreach( QString filename, filenames ) {
		QTest::newRow( qPrintable( QFileInfo( filename ).fileName() ) ) << filename;
	}
}

void XmlParserBenchmark::oracleParser_data() {
	QStringList filenames = listOfXml();

	QTest::addColumn<QString>( "filename" );
	QTest::newRow( "no parse" ) << QString();
	foreach( QString filename, filenames ) {
		QTest::newRow( qPrintable( QFileInfo( filename ).fileName() ) ) << filename;
	}
}

void XmlParserBenchmark::scewParser_data() {
	QStringList filenames = listOfXml();

	QTest::addColumn<QString>( "filename" );
	foreach( QString filename, filenames ) {
		QTest::newRow( qPrintable( QFileInfo( filename ).fileName() ) ) << filename;
	}
}

void XmlParserBenchmark::tinyXmlParser_data() {
	QStringList filenames = listOfXml();

	QTest::addColumn<QString>( "filename" );
	foreach( QString filename, filenames ) {
		QTest::newRow( qPrintable( QFileInfo( filename ).fileName() ) ) << filename;
	}
}

void XmlParserBenchmark::xercesCppParser_data() {
	QStringList filenames = listOfXml();

	QTest::addColumn<QString>( "filename" );
	foreach( QString filename, filenames ) {
		QTest::newRow( qPrintable( QFileInfo( filename ).fileName() ) ) << filename;
	}
}

void XmlParserBenchmark::qtDomParser() {
	QFETCH( QString, filename );
	QBENCHMARK {
		parseWithQtDomParser( filename );
    }
}

void XmlParserBenchmark::libxml2DomParser() {
	QFETCH( QString, filename );
	QBENCHMARK {
		parseWithLibxml2DomParser( filename );
    }
}

void XmlParserBenchmark::libexpatParser() {
	QFETCH( QString, filename );
	QBENCHMARK {
		parseWithExpatParser( filename );
    }
}

void XmlParserBenchmark::oracleParser() {
	QFETCH( QString, filename );

	QBENCHMARK {
		parseWithOracleParser( filename );
	}
}

void XmlParserBenchmark::scewParser() {
	QFETCH( QString, filename );
	QBENCHMARK {
		parseWithScewParser( filename );
    }
}

void XmlParserBenchmark::tinyXmlParser() {
	QFETCH( QString, filename );
	QBENCHMARK {
		parseWithTinyXmlParser( filename );
    }
}

void XmlParserBenchmark::xercesCppParser() {
	QFETCH( QString, filename );
	QBENCHMARK {
		parseWithXercesCppParser( filename );
    }
}

QTEST_MAIN(XmlParserBenchmark)
